package com.dcsoft.system.ladder.mapper;

import com.dcsoft.system.ladder.domain.DevicePositionVo;
import com.dcsoft.system.ladder.domain.DeviceTreeVo;
import com.dcsoft.system.ladder.domain.TLadderRule;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 梯控规则Mapper接口
 *
 * @author dcsoft
 * @date 2023-12-26
 */
public interface TLadderRuleMapper {
    /**
     * 查询梯控规则
     *
     * @param id 梯控规则主键
     * @return 梯控规则
     */
    public TLadderRule selectTLadderRuleById(@Param("id") String id);

    /**
     * 查询梯控规则列表
     *
     * @param tLadderRule 梯控规则
     * @return 梯控规则集合
     */
    public List<TLadderRule> selectTLadderRuleList(TLadderRule tLadderRule);

    /**
     * 新增梯控规则
     *
     * @param tLadderRule 梯控规则
     * @return 结果
     */
    public int insertTLadderRule(TLadderRule tLadderRule);

    /**
     * 修改梯控规则
     *
     * @param tLadderRule 梯控规则
     * @return 结果
     */
    public int updateTLadderRule(TLadderRule tLadderRule);

    /**
     * 删除梯控规则
     *
     * @param id 梯控规则主键
     * @return 结果
     */
    public int deleteTLadderRuleById(Long id);

    /**
     * 批量删除梯控规则
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTLadderRuleByIds(String[] ids);

    /**
     * 查询设备位置信息
     */
    List<DeviceTreeVo> queryDevicePositionTree();

    /**
     * 查询规则是否已授权
     */
    List<TLadderRule> queryEmpower(String[] ids);
}
